/*
 * hal.h - hardware definition
 *
 * (c) Axel (XL) Schwenke, axel.schwenke@gmx.net
 *
 * $Id: hal.h 244 2014-02-08 22:36:10Z schwenke $
 */

#ifndef HAL_H
#define HAL_H

/*
            ATMEGA328P Pinout
            -----------------
      ISP |Res            PC5| RS
      DB0 |PD0            PC4| R/W
      DB1 |PD1            PC3| E
      DB2 |PD2            PC2|
      DB3 |PD3            PC1| PSB
      DB4 |PD4            PC0|
      +5V |Vcc            GND| GND
      GND |GND           ARef| +5V
          |XTAL1         AVcc| +5V
          |XTAL2          SCK| ISP
      DB5 |PD5           MISO| ISP
      DB6 |PD6           MOSI| ISP
      DB7 |PD7            PB2| RST
          |PB0            PB1|
           ------------------

DB0 - DB7 .... Data Bus for LCD
RS, R/W, E ... LCD control
PSB,RST ...... LCD control
ISP .......... to ISP connector

*/

#include <avr/io.h>

/* Port B */
#define RST             2

/* Port C */
#define RS		5
#define RW		4
#define EN		3
#define PSB		1

/* display pseudo functions */
#define st7920_reset_H()          PORTB |=  (1<<RST)
#define st7920_reset_L()          PORTB &= ~(1<<RST)
#define st7920_E_H()              PORTC |=  (1<<EN)
#define st7920_E_L()              PORTC &= ~(1<<EN)
#define st7920_select_data()      PORTC |=  (1<<RS)
#define st7920_select_command()   PORTC &= ~(1<<RS)
#define st7920_select_read()      PORTC |=  (1<<RW)
#define st7920_select_write()     PORTC &= ~(1<<RW)
#define st7920_port_input()       DDRD = 0x00
#define st7920_port_output()      DDRD = 0xFF
#define st7920_port_read()        (PIND)
#define st7920_port_write(x)      PORTD = (x)

#endif /* HAL_H */
