/**********************************************************************
 *                                                                    *
 * Graphic Mode Library for Sitronix ST7920 based GLCD                *
 *                                                                    *
 * (c) Axel (XL) Schwenke <axel.schwenke@gmx.net>                     *
 *                                                                    *
 * $Id: st7920.h 245 2014-02-08 22:37:56Z schwenke $
 *                                                                    *
 **********************************************************************/

#ifndef ST7920_H
#define ST7920_H

#include <inttypes.h>

/* LCD size */
#define ST7920_WIDTH 128
#define ST7920_HEIGHT 64

/*
 * there is nothing to be configured below
 */

typedef enum {
    set, clear, invert
} st7920_mode;

typedef enum {
    front, back
} st7920_screen;

/* check if display size makes sense */
#if (ST7920_WIDTH < 64 || ST7920_WIDTH > 256)
#error ST7920_WIDTH out of range [64..256]
#endif

#if (ST7920_HEIGHT < 32 || ST7920_HEIGHT > 64)
#error ST7920_HEIGHT out of range [32..64]
#endif

void st7920_init(void);
void st7920_set_mode(st7920_mode m);
void st7920_set_screen(st7920_screen s);
void st7920_swap(void);
void st7920_clear(void);
void st7920_putpixel(uint8_t x, uint8_t y);
void st7920_hline(uint8_t x1, uint8_t y1, uint8_t x2);

#endif /* ST7920_H */
